@@ -1,6 +1,11 @@
 /*
- *  Authors: Rodney Dawes <dobey@ximian.com>
+ *  Moblin Background Management Application
+ *  Source: capplets/background/wp-capplet.c
+ *  Author: Todd Brandt <todd.e.brandt@intel.com>
+ *  Copyright 2007-2008 Intel Corp (moblin.org)
  *
+ *  Based on capplets/background/gnome-wp-capplet.c from
+ *  gnome-control-center-2.18.1: Rodney Dawes <dobey@ximian.com>
  *  Copyright 2003-2006 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -19,7 +24,6 @@
  */
 
 #include "wp-capplet.h"
-#include <hildon-cp-plugin/hildon-cp-plugin-interface.h>
 
 /* global data */
 gchar *original_filename = NULL;
