@@ -1,6 +1,11 @@
 /*
- *  Authors: Rodney Dawes <dobey@ximian.com>
+ *  Moblin Background Management Application
+ *  Source: capplets/background/wp-database.h
+ *  Author: Todd Brandt <todd.e.brandt@intel.com>
+ *  Copyright 2007-2008 Intel Corp (moblin.org)
  *
+ *  Based on capplets/background/gnome-wp-database.h from
+ *  gnome-control-center-2.18.1: Rodney Dawes <dobey@ximian.com>
  *  Copyright 2003-2006 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -18,10 +23,9 @@
  *
  */
 
-#ifndef _GNOME_WP_XML_H_
-#define _GNOME_WP_XML_H_
+#ifndef _MOBLIN_WP_DATABASE_H_
+#define _MOBLIN_WP_DATABASE_H_
 
 void load_images (MoblinWPCapplet * capplet);
 
 #endif
-
