@@ -1,6 +1,11 @@
 /*
- *  Authors: Rodney Dawes <dobey@ximian.com>
+ *  Moblin Background Management Application
+ *  Source: capplets/background/wp-info.h
+ *  Author: Todd Brandt <todd.e.brandt@intel.com>
+ *  Copyright 2007-2008 Intel Corp (moblin.org)
  *
+ *  Based on capplets/background/gnome-wp-info.h from
+ *  gnome-control-center-2.18.1: Rodney Dawes <dobey@ximian.com>
  *  Copyright 2003-2006 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -18,8 +23,8 @@
  *
  */
 
-#ifndef _GNOME_WP_INFO_H_
-#define _GNOME_WP_INFO_H_
+#ifndef _MOBLIN_WP_INFO_H_
+#define _MOBLIN_WP_INFO_H_
 
 #include <glib.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -32,15 +37,12 @@ struct _MoblinWPInfo {
   gchar * thumburi;
   gchar * name;
   gchar * mime_type;
-
   GnomeVFSFileSize size;
-
   time_t mtime;
 };
 
 MoblinWPInfo * moblin_wp_info_new (const gchar * uri,
 				 GnomeThumbnailFactory * thumbs);
-MoblinWPInfo * moblin_wp_info_dup (const MoblinWPInfo * info);
 void moblin_wp_info_free (MoblinWPInfo * info);
 
 #endif
