@@ -1,6 +1,11 @@
 /*
- *  Authors: Rodney Dawes <dobey@ximian.com>
+ *  Moblin Background Management Application
+ *  Source: capplets/background/wp-utils.h
+ *  Author: Todd Brandt <todd.e.brandt@intel.com>
+ *  Copyright 2007-2008 Intel Corp (moblin.org)
  *
+ *  Based on capplets/background/gnome-wp-utils.h from
+ *  gnome-control-center-2.18.1: Rodney Dawes <dobey@ximian.com>
  *  Copyright 2003-2006 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -18,8 +23,8 @@
  *
  */
 
-#ifndef _GNOME_WP_UTILS_H_
-#define _GNOME_WP_UTILS_H_
+#ifndef _MOBLIN_WP_UTILS_H_
+#define _MOBLIN_WP_UTILS_H_
 
 #include <glib.h>
 #include <gtk/gtk.h>
