@@ -1,12 +1,16 @@
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 
+#include <glib.h>
 #include <string.h>
-#include <hildon-cp-plugin/hildon-cp-plugin-interface.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
+#include <glib-object.h>
 #include <glade/glade.h>
+#include <gconf/gconf-client.h>
+#include <hildon-cp-plugin/hildon-cp-plugin-interface.h>
 #include <gdk/gdkx.h>
-
+#include "gconf-property-editor.h"
 #include <X11/extensions/Xrandr.h>
 
 #include "capplet-util.h"
