@@ -22,6 +22,7 @@ FILE *logfp = NULL;
 #endif
 
 MoblinSystemServer *dbusserver = NULL;
+GQuark error_quark = 0;
 
 static void
 sig_handler(int num)
@@ -53,6 +54,7 @@ GMainLoop *loop = NULL;
 
 	signal(SIGTERM, sig_handler);
 
+	error_quark = g_quark_from_static_string ("moblin-system-daemon-error-quark");
 	loop = g_main_loop_new(NULL,FALSE);
 
 #ifdef LOGDEBUG
