@@ -63,6 +63,8 @@ typedef struct{
         DBusGProxy *proxy;
         DBusGConnection *connection;
         gchar *udi;
+        guint min_level;
+        guint max_level;
         guint level;
         void (*brightness_changed_cb)(DBusGProxy*, guint, struct _BrightnessControl*);
 } MoblinBrightnessApplet;
@@ -166,7 +168,7 @@ moblin_applet_draw_cb (MoblinBrightnessApplet *applet)
 		return FALSE;
 	}
 
-	n = (4*applet->level)/(MAX_BRIGHTNESS_LEVEL - MIN_BRIGHTNESS_LEVEL + 1);
+	n = (4*(applet->level))/((applet->max_level)-(applet->min_level)+1);
 	if(n > 3) n = 3;
 	if(n < 0) n = 0;
 
@@ -226,8 +228,8 @@ static void
 moblin_applet_update_popup_level (MoblinBrightnessApplet *applet)
 {
 	if (applet->popup != NULL) {
-		gtk_widget_set_sensitive (applet->btn_plus, applet->level < MAX_BRIGHTNESS_LEVEL);
-		gtk_widget_set_sensitive (applet->btn_minus, applet->level > MIN_BRIGHTNESS_LEVEL);
+		gtk_widget_set_sensitive (applet->btn_plus, applet->level < applet->max_level);
+		gtk_widget_set_sensitive (applet->btn_minus, applet->level > applet->min_level);
 		gtk_range_set_value (GTK_RANGE(applet->slider), (guint) applet->level);
 	}
 	moblin_applet_update_tooltip (applet);
@@ -243,7 +245,7 @@ moblin_applet_update_popup_level (MoblinBrightnessApplet *applet)
 static gboolean
 moblin_applet_plus_cb (GtkWidget *w, MoblinBrightnessApplet *applet)
 {
-	if (applet->level < MAX_BRIGHTNESS_LEVEL) {
+	if (applet->level < applet->max_level) {
 		applet->level++;
 	}
 	applet->call_worked = set_brightness ((BrightnessControl*)&(applet->proxy));
@@ -262,7 +264,7 @@ moblin_applet_plus_cb (GtkWidget *w, MoblinBrightnessApplet *applet)
 static gboolean
 moblin_applet_minus_cb (GtkWidget *w, MoblinBrightnessApplet *applet)
 {
-	if (applet->level > MIN_BRIGHTNESS_LEVEL) {
+	if (applet->level > applet->min_level) {
 		applet->level--;
 	}
 	applet->call_worked = set_brightness ((BrightnessControl*)&(applet->proxy));
@@ -333,8 +335,8 @@ moblin_applet_create_popup (MoblinBrightnessApplet *applet)
 	moblin_applet_destroy_popup_cb (applet);
 
 	/* slider */
-	applet->slider = gtk_vscale_new_with_range (MIN_BRIGHTNESS_LEVEL, 
-		MAX_BRIGHTNESS_LEVEL, 1);
+	applet->slider = gtk_vscale_new_with_range (applet->min_level, 
+		applet->max_level, 1);
 	gtk_widget_set_size_request (applet->slider, SLIDER_WIDTH, 200);
 	gtk_range_set_inverted (GTK_RANGE(applet->slider), TRUE);
 	gtk_scale_set_draw_value (GTK_SCALE(applet->slider), FALSE);
@@ -530,7 +532,8 @@ moblin_brightness_applet_init (MoblinBrightnessApplet *applet)
 	gtk_container_add (GTK_CONTAINER (applet), image);
 	gtk_widget_show (image);
 
-	brightness_dbus_connect ((BrightnessControl*)&(applet->proxy));
+	if(!brightness_dbus_connect((BrightnessControl*)&(applet->proxy)))
+		return;
 
 	/* coldplug */
 	applet->call_worked = get_brightness ((BrightnessControl*)&(applet->proxy));
